==> giftool2-0.10.0.tar.gz: giftool2-0.10.0/README.md <==
# giftool2

A simple tool to create GIFs from videos.

## Features

- Convert videos to GIFs
- Upload a video file
- Select a start and end time for the GIF
- preview the start and end frames
- Create and download the GIF

## Usage

1. Installation: `uv add gif-tool2` or  `pip install gif-tool2`

2. Run the app:  `gif-tool2`

## User Interface

The app has a simple and intuitive user interface. You can upload a video file, select the start and end time for the GIF, and preview the start and end frames. Once you are satisfied with your selection, you can create and download the GIF.

![img](./homepage800x600.jpg)

## License

This project is licensed under the [MIT License](LICENSE).
MIT License

Copyright (c) 2024 [Michael Dini]

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> giftool2-0.11.0.tar.gz: giftool2-0.11.0/README.md <==
# giftool2

A simple tool to create GIFs from videos.

## Features

- Convert videos to GIFs
- Upload a video file
- Select a start and end time for the GIF
- preview the start and end frames
- Create and download the GIF

## Usage

1. Installation: `uv add gif-tool2` or  `pip install gif-tool2`

2. Run the app:  `gif-tool2`

## User Interface

The app has a simple and intuitive user interface. You can upload a video file, select the start and end time for the GIF, and preview the start and end frames. Once you are satisfied with your selection, you can create and download the GIF.

![./homepage800x600.jpg](https://github.com/michaeldini/giftool2/blob/0f6ed9d3fb67ce9fc881f688551e950a1853312b/homepage800x600.jpg)

## License

This project is licensed under the [MIT License](LICENSE).
MIT License

Copyright (c) 2024 [Michael Dini]

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
